==> haskell-xml-conduit-1.3.5-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.3.5
id: xml-conduit-1.3.5-EeS767uhAnf9MakOf5XnJx
key: xml-conduit-1.3.5-EeS767uhAnf9MakOf5XnJx
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
exposed: True
exposed-modules:
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
    Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
hidden-modules: Text.XML.Stream.Token
abi: 14886994ac835a8962e3c08f7d45ed74
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/xml-conduit-1.3.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/xml-conduit-1.3.5
data-dir: /usr/share/arm-linux-ghc-8.0.1/xml-conduit-1.3.5
hs-libraries: HSxml-conduit-1.3.5-EeS767uhAnf9MakOf5XnJx
depends:
    attoparsec-0.13.0.2-4oqBQA8Yjg9Kon1ukf0gbT base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.2-2ceCZ3Fm7x67ZwaaR7uQ3C
    blaze-markup-0.7.1.0-BKRb0wHFpEyDJWTsyjQqnp bytestring-0.10.8.1
    conduit-1.2.7-1fFSFiPEs5YE08sG4lN9Z3
    conduit-extra-1.1.13.2-CPtzSyRlb4w7sgNGBWFen3 containers-0.5.7.1
    data-default-0.7.1.1-IrbTxn4APE83ZiDGILskO deepseq-1.4.2.0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    resourcet-1.1.7.5-3j9hqcrUWUtEP6gwxkGxax
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    xml-types-0.3.6-KjWhtX04gsiBko21cGwOxT
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-conduit-1.3.5-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.3.5
id: xml-conduit-1.3.5-CdIwocMiHG5EhjTqrZS2jf
key: xml-conduit-1.3.5-CdIwocMiHG5EhjTqrZS2jf
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
exposed: True
exposed-modules:
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
    Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
hidden-modules: Text.XML.Stream.Token
abi: a9b50d7ae7b486ca9cfa713968b9fd33
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/xml-conduit-1.3.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/xml-conduit-1.3.5
data-dir: /usr/share/arm-linux-ghc-8.0.1/xml-conduit-1.3.5
hs-libraries: HSxml-conduit-1.3.5-CdIwocMiHG5EhjTqrZS2jf
depends:
    attoparsec-0.13.0.2-4oqBQA8Yjg9Kon1ukf0gbT base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.2-2ceCZ3Fm7x67ZwaaR7uQ3C
    blaze-markup-0.7.1.0-BKRb0wHFpEyDJWTsyjQqnp bytestring-0.10.8.1
    conduit-1.2.7-1fFSFiPEs5YE08sG4lN9Z3
    conduit-extra-1.1.13.2-CPtzSyRlb4w7sgNGBWFen3 containers-0.5.7.1
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr deepseq-1.4.2.0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    resourcet-1.1.7.5-3j9hqcrUWUtEP6gwxkGxax
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    xml-types-0.3.6-KjWhtX04gsiBko21cGwOxT
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
